from .base_reward_model import BaseRewardModel, create_reward_model, get_reward_model_cls
# inverse RL
from .pdeil_irl_model import PdeilRewardModel
from .gail_irl_model import GailRewardModel
from .pwil_irl_model import PwilRewardModel
from .red_irl_model import RedRewardModel
from .trex_reward_model import TrexRewardModel
# sparse reward
from .her_reward_model import HerRewardModel
# exploration
from .rnd_reward_model import RndRewardModel
from .guided_cost_reward_model import GuidedCostRewardModel
from .ngu_reward_model import RndNGURewardModel, EpisodicNGURewardModel
from .icm_reward_model import ICMRewardModel
